{% extends "bee_django_crm/base.html" %}
{% load bee_django_crm_filter %}
{% load static %}
{% block content %}
    {% include 'bee_django_crm/logo.html' %}
    {% include 'bee_django_crm/nav.html' %}
    <h4>缴费详情</h4>
    {% if not preuser_contract.is_checked %}
        <a href="{% url 'bee_django_crm:preuser_contract_update' preuser_contract.id %}">修改</a>
    {% endif %}
    <table class="table">
        <tr>
            <td>缴费人</td>
            <td>{{ preuser_contract.preuser.name }}</td>
        </tr>
        <tr>
            <td>合同</td>
            <td>{{ preuser_contract.contract.name }}</td>
        </tr>
        <tr>
            <td>合同时长</td>
            <td>{{ preuser_contract.contract.duration }} * {{ preuser_contract.contract.period }} 天</td>
        </tr>
        <tr>
            <td>合同金额</td>
            <td>
                {{ preuser_contract.contract.price }}
            </td>
        </tr>
        <tr>
            <td>实际缴费金额</td>
            <td>
                {{ preuser_contract.price }}
            </td>
        </tr>
        <tr>
            <td>缴费日期</td>
            <td>
                {{ preuser_contract.paid_at|local_datetime|date:"Y-m-d" }}
            </td>
        </tr>
        <tr>
            <td>开始日期</td>
            <td>
                {{ preuser_contract.study_at|local_datetime|date:"Y-m-d" }}
            </td>
        </tr>
        <tr>
            <td>备注</td>
            <td>
                {{ preuser_contract.info }}
            </td>
        </tr>
        <tr>
            <td></td>
            <td>
                {% if not preuser_contract.is_checked %}
                    <a href="#" id="check_{{ preuser_contract.id }}"
                       data-confirm="{% url "bee_django_crm:preuser_contract_update_check" preuser_contract.id %}"
                       onclick="click_check(this)">审核</a>
                {% else %}
                    {% if preuser_contract.checked_by %}
                        由【{{ preuser_contract.checked_by|get_checked_user_name }}】
                    {% endif %}
                    于【{{ preuser_contract.checked_at|local_datetime|date:"Y-m-d H:i:s" }}】审核
                    {% if after_check_url %}

                        {% if preuser_contract.after_checked_at %}
                            ，【{{ preuser_contract.after_checked_at|local_datetime|date:"Y-m-d H:i:s" }}】完成后续操作
                        {% else %}
                            <a href="{{ after_check_url }}?preuser_id={{ preuser_contract.preuser.id }}&preuser_contract_id={{ preuser_contract.id }}">后续操作</a>
                        {% endif %}
                    {% endif %}
                {% endif %}
            </td>
        </tr>


    </table>

{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {

        });
        function click_check(_this) {
            if (!confirm('确认要执行这个操作？')) {
                return false;
            }
            var url = $(_this).attr('data-confirm');
            $.post(url).done(function (data) {
                alert('审核成功!');

                location.href = data.url;
            });
        }
    </script>
{% endblock %}