<style>
    .nav {
        background-color: #4B6788;
        height: 40px;
        color: #ffffff;
        line-height: 40px;
        padding: 0 10px;
    }

    .nav a {
        color: #ffffff;
    }
</style>
<div class="nav">
    <a href="{% url 'bee_django_crm:preuser_list' %}?level=1">会员管理</a> |
    <a href="{% url 'bee_django_crm:application_question_list' %}">申请表管理</a> |
    <a href="{% url 'bee_django_crm:source_list' %}">渠道管理</a> |
    <a href="{% url 'bee_django_crm:contract_list' %}">合同管理</a> |
    <a href="{% url 'bee_django_crm:preuser_all_contract_list' %}">费用管理</a> |
{#    <a href="{% url 'bee_django_crm:poster_list' %}">海报管理</a> |#}

</div>